Top

    Spanish NCQ
    Alboraya (Valencia), Spain
    February 12th 2005
    3R+F
    34 players
    Jose Vicente Coll

    Crypt (13 cards, min=14, max=25, avg=5.08)
    ------------------------------------------
    3x Jost Werner			6   AUS PRE ani			Toreador antitribu:2
    2x Le Dinh Tho			5   NEC aus dom			Nagaraja:2
    1x Greta Kircher		7   AUS CEL PRE obf		Toreador antitribu:2
    1x Ian Wallingford		6   CEL PRE aus		bishop	Toreador antitribu:2
    1x Sheila Mezarin		6   AUS PRE cel for		Toreador antitribu:2
    1x Creamy Jade			5   PRE aus cel vic		Toreador antitribu:3
    1x Mercy, Knight Inquisitor	5   AUS cel dom pre		Toreador antitribu:2
    1x Remilliard, Devout Crusader	4   AUS pre			Toreador antitribu:2
    1x Lolita			3   for pre			Toreador antitribu:2
    1x Nicholas Chang		2   aus				Toreador antitribu:3

    Library:

    Master:
    4 x Palla Grande
    3 x Direct Intervention
    3 x Blodd Doll
    2 x Pentex Subversion
    2 x Anarch Troublemaker
    1 x Hungry Coyote
    1 x Fetish Club H.G.
    1 x Sudden Reversal
    1 x Creepshow Casino
    1 x The Coven

    Action:
    8 x Art Scam
    8 x The Embrace
    4 x Mind Numb
    4 x Enchant Kindred
    2 x Entrancement
    2 x Marijava Ghoul
    2 x Revelations
    1 x Owl Companion

    Action Modifier:
    8 x Change of Target

    Reaction:
    5 x Wake...
    1 x Delaying
    7 x Telepathic Misdirection
    2 x Telepathic Counter
    3 x My Enemy's Enemy
    2 x Eagle's Sight
    2 x Enhanced Senses

    Combat:
    7 x Majesty
    3 x Staredown